@@ -51,11 +51,11 @@ gboolean __e_book_backend_google_debug__;
 static EBookBackendSyncStatus e_book_backend_status_from_google_book_error (GoogleBookError error_code);
 
 static EBookBackendSyncStatus
-e_book_backend_google_create_contact (EBookBackendSync 	*backend,
+e_book_backend_google_create_contact (EBookBackendSync	*backend,
 				      EDataBook		*book,
-				      guint32 		opid,
-				      const char 	*vcard_str,
-				      EContact 		**out_contact)
+				      guint32		opid,
+				      const gchar	*vcard_str,
+				      EContact		**out_contact)
 {
     EBookBackendGooglePrivate *priv;
     EBookBackendSyncStatus status = GNOME_Evolution_Addressbook_OtherError;
@@ -88,10 +88,10 @@ e_book_backend_google_create_contact (EBookBackendSync 	*backend,
 
 static EBookBackendSyncStatus
 e_book_backend_google_remove_contacts (EBookBackendSync *backend,
-				       EDataBook 	*book,
-				       guint32 		opid,
-				       GList 		*id_list,
-				       GList 		**ids)
+				       EDataBook	*book,
+				       guint32		opid,
+				       GList		*id_list,
+				       GList		**ids)
 {
     EBookBackendGooglePrivate *priv;
     EBookBackendSyncStatus status = GNOME_Evolution_Addressbook_OtherError;
@@ -108,7 +108,7 @@ e_book_backend_google_remove_contacts (EBookBackendSync *backend,
 
     for (id_iter = id_list; id_iter; id_iter = id_iter->next) {
 	GError *error = NULL;
-	const char *uid;
+	const gchar *uid;
 
 	uid = id_iter->data;
 	google_book_remove_contact (priv->book, uid, &error);
@@ -129,11 +129,11 @@ e_book_backend_google_remove_contacts (EBookBackendSync *backend,
 }
 
 static EBookBackendSyncStatus
-e_book_backend_google_modify_contact (EBookBackendSync 	*backend,
+e_book_backend_google_modify_contact (EBookBackendSync	*backend,
 				      EDataBook		*book,
-				      guint32 		opid,
-				      const char 	*vcard_str,
-				      EContact 		**out_contact)
+				      guint32		opid,
+				      const gchar	*vcard_str,
+				      EContact		**out_contact)
 {
     EBookBackendGooglePrivate *priv;
     EBookBackendSyncStatus status = GNOME_Evolution_Addressbook_OtherError;
@@ -165,11 +165,11 @@ e_book_backend_google_modify_contact (EBookBackendSync 	*backend,
 }
 
 static EBookBackendSyncStatus
-e_book_backend_google_get_contact (EBookBackendSync 	*backend,
-				   EDataBook 		*book,
-				   guint32 		opid,
-				   const char 		*uid,
-				   char 		**vcard_str)
+e_book_backend_google_get_contact (EBookBackendSync	*backend,
+				   EDataBook		*book,
+				   guint32		opid,
+				   const gchar		*uid,
+				   gchar		**vcard_str)
 {
     EBookBackendGooglePrivate *priv;
     EBookBackendSyncStatus status = GNOME_Evolution_Addressbook_OtherError;
@@ -194,10 +194,10 @@ e_book_backend_google_get_contact (EBookBackendSync 	*backend,
 
 static EBookBackendSyncStatus
 e_book_backend_google_get_contact_list (EBookBackendSync *backend,
-					EDataBook 	 *book,
-					guint32 	 opid,
-					const char 	 *query,
-					GList 		 **contacts)
+					EDataBook	 *book,
+					guint32	 opid,
+					const gchar	 *query,
+					GList		 **contacts)
 {
     EBookBackendGooglePrivate *priv;
     EBookBackendSyncStatus status = GNOME_Evolution_Addressbook_OtherError;
@@ -224,7 +224,7 @@ e_book_backend_google_get_contact_list (EBookBackendSync *backend,
 
 	contact = all_contacts->data;
 	if (e_book_backend_sexp_match_contact (sexp, contact)) {
-	    char *vcard_str;
+	    gchar *vcard_str;
 	    vcard_str = e_vcard_to_string (E_VCARD (contact), EVC_FORMAT_VCARD_30);
 	    *contacts = g_list_append (*contacts, vcard_str);
 	}
@@ -250,7 +250,7 @@ on_google_book_contact_added (GoogleBook *book, EContact *contact, gpointer user
 }
 
 static void
-on_google_book_contact_removed (GoogleBook *book, const char *uid, gpointer user_data)
+on_google_book_contact_removed (GoogleBook *book, const gchar *uid, gpointer user_data)
 {
     EBookBackendGooglePrivate *priv;
     GList *iter;
@@ -342,16 +342,16 @@ e_book_backend_google_stop_book_view (EBookBackend  *backend,
 
 static EBookBackendSyncStatus
 e_book_backend_google_authenticate_user (EBookBackendSync *backend,
-					 EDataBook 	  *book,
-					 guint32 	  opid,
-					 const char 	  *username,
-					 const char 	  *password,
-					 const char 	  *auth_method)
+					 EDataBook	  *book,
+					 guint32	  opid,
+					 const gchar	  *username,
+					 const gchar	  *password,
+					 const gchar	  *auth_method)
 {
     EBookBackendGooglePrivate *priv;
     EBookBackendSyncStatus status = GNOME_Evolution_Addressbook_Success;
     GError *error = NULL;
-    char *book_username;
+    gchar *book_username;
     gboolean match;
 
     __debug__ (G_STRFUNC);
@@ -390,12 +390,12 @@ e_book_backend_google_authenticate_user (EBookBackendSync *backend,
 }
 
 static EBookBackendSyncStatus
-e_book_backend_google_get_supported_auth_methods (EBookBackendSync 	*backend,
-						  EDataBook 		*book,
-						  guint32 		opid,
-						  GList 		**methods)
+e_book_backend_google_get_supported_auth_methods (EBookBackendSync	*backend,
+						  EDataBook		*book,
+						  guint32		opid,
+						  GList		**methods)
 {
-    char *auth_method;
+    gchar *auth_method;
 
     __debug__ (G_STRFUNC);
     auth_method = g_strdup_printf ("plain/password");
@@ -405,10 +405,10 @@ e_book_backend_google_get_supported_auth_methods (EBookBackendSync 	*backend,
 }
 
 static EBookBackendSyncStatus
-e_book_backend_google_get_required_fields (EBookBackendSync 	*backend,
-					   EDataBook 		*book,
-					   guint32 		opid,
-					   GList 		**fields_out)
+e_book_backend_google_get_required_fields (EBookBackendSync	*backend,
+					   EDataBook		*book,
+					   guint32		opid,
+					   GList		**fields_out)
 {
     __debug__ (G_STRFUNC);
 
@@ -417,12 +417,12 @@ e_book_backend_google_get_required_fields (EBookBackendSync 	*backend,
 }
 
 static EBookBackendSyncStatus
-e_book_backend_google_get_supported_fields (EBookBackendSync 	*backend,
-					    EDataBook 		*book,
-					    guint32 		opid,
-					    GList 		**fields_out)
+e_book_backend_google_get_supported_fields (EBookBackendSync	*backend,
+					    EDataBook		*book,
+					    guint32		opid,
+					    GList		**fields_out)
 {
-    const int supported_fields[] =
+    const gint supported_fields[] =
     {
 	E_CONTACT_FULL_NAME,
 	E_CONTACT_EMAIL_1,
@@ -452,12 +452,12 @@ e_book_backend_google_get_supported_fields (EBookBackendSync 	*backend,
 	E_CONTACT_ADDRESS_OTHER
     };
     GList *fields = NULL;
-    int i;
+    gint i;
 
     __debug__ (G_STRFUNC);
 
     for (i = 0; i < G_N_ELEMENTS (supported_fields); i++) {
-	const char *field_name;
+	const gchar *field_name;
 
 	field_name = e_contact_field_name (supported_fields[i]);
 	fields = g_list_append (fields, g_strdup (field_name));
@@ -468,20 +468,20 @@ e_book_backend_google_get_supported_fields (EBookBackendSync 	*backend,
 }
 
 static EBookBackendSyncStatus
-e_book_backend_google_get_changes (EBookBackendSync 	*backend,
-				   EDataBook 		*book,
-				   guint32 		opid,
-				   const char 		*change_id,
-				   GList 		**changes_out)
+e_book_backend_google_get_changes (EBookBackendSync	*backend,
+				   EDataBook		*book,
+				   guint32		opid,
+				   const gchar		*change_id,
+				   GList		**changes_out)
 {
     __debug__ (G_STRFUNC);
     return GNOME_Evolution_Addressbook_OtherError;
 }
 
 static EBookBackendSyncStatus
-e_book_backend_google_remove (EBookBackendSync 	*backend,
+e_book_backend_google_remove (EBookBackendSync	*backend,
 			      EDataBook		*book,
-			      guint32 		opid)
+			      guint32		opid)
 {
     __debug__ (G_STRFUNC);
     return GNOME_Evolution_Addressbook_Success;
@@ -496,14 +496,14 @@ on_google_book_auth_required (GoogleBook *book, gpointer user_data)
 
 static GNOME_Evolution_Addressbook_CallStatus
 e_book_backend_google_load_source (EBookBackend *backend,
-				   ESource 	*source,
-				   gboolean 	only_if_exists)
+				   ESource	*source,
+				   gboolean	only_if_exists)
 {
     EBookBackendGooglePrivate *priv = GET_PRIVATE (backend);
-    const char *refresh_interval_str, *use_ssl_str, *use_cache_str;
+    const gchar *refresh_interval_str, *use_ssl_str, *use_cache_str;
     guint refresh_interval;
     gboolean use_ssl, use_cache;
-    const char *username;
+    const gchar *username;
 
     if (priv->book) {
 	g_warning ("Source already loaded!");
@@ -564,7 +564,7 @@ e_book_backend_google_load_source (EBookBackend *backend,
     return GNOME_Evolution_Addressbook_Success;
 }
 
-static char *
+static gchar *
 e_book_backend_google_get_static_capabilities (EBookBackend *backend)
 {
     __debug__ (G_STRFUNC);
