@@ -6,7 +6,7 @@
  * Author:
  *   Nat Friedman (nat@ximian.com)
  *
- * Copyright 2000, Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
 #ifndef __E_BOOK_LISTENER_H__
@@ -96,7 +96,7 @@ struct _EBookListenerResponse {
 	GList                                    *list;
 
 	/* For ProgressEvent */
-	char                   *msg;
+	gchar                   *msg;
 	short                   percent;
 
 	/* For LinkStatusEvent */
@@ -106,11 +106,10 @@ struct _EBookListenerResponse {
 	gboolean                writable;
 
 	/* For Card[Added|Removed|Modified]Event */
-	char                   *id;
-	char                   *vcard;
+	gchar                   *id;
+	gchar                   *vcard;
 };
 
-
 EBookListener         *e_book_listener_new            (void);
 GType                  e_book_listener_get_type       (void);
 void                   e_book_listener_stop           (EBookListener *listener);
