@@ -20,7 +20,6 @@
  * Boston, MA 02110-1301, USA.
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -49,7 +48,6 @@
 #include <libecal/e-cal-component.h>
 #include <libecal/e-cal-time-util.h>
 
-
 #include <libical/ical.h>
 #include <libsoup/soup-misc.h>
 
@@ -95,7 +93,7 @@ e_cal_backend_google_utils_populate_cache (ECalBackendGoogle *cbgo)
 	kind = e_cal_backend_get_kind (E_CAL_BACKEND(cbgo));
 	temp = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
 
- 	item = e_cal_backend_google_get_item (cbgo);
+	item = e_cal_backend_google_get_item (cbgo);
 	entries = gdata_feed_get_entries (item->feed);
 	priv = cbgo->priv;
 
@@ -107,7 +105,7 @@ e_cal_backend_google_utils_populate_cache (ECalBackendGoogle *cbgo)
 			e_cal_component_commit_sequence (comp);
 			comp_str = e_cal_component_get_as_string (comp);
 
-			e_cal_backend_notify_object_created (E_CAL_BACKEND(cbgo), (const char *)comp_str);
+			e_cal_backend_notify_object_created (E_CAL_BACKEND(cbgo), (const gchar *)comp_str);
 			e_cal_backend_cache_put_component (cache, comp);
 			g_object_unref (comp);
 			g_free (comp_str);
@@ -117,7 +115,6 @@ e_cal_backend_google_utils_populate_cache (ECalBackendGoogle *cbgo)
 	e_cal_backend_notify_view_done (E_CAL_BACKEND(cbgo), GNOME_Evolution_Calendar_Success);
 }
 
-
 /**
  *
  * e_cal_backend_google_utils_create_cache:
@@ -129,7 +126,7 @@ static gpointer
 e_cal_backend_google_utils_create_cache (ECalBackendGoogle *cbgo)
 {
 	ESource *source;
-	int x;
+	gint x;
 	const gchar *refresh_interval = NULL;
 	ECalBackendCache *cache;
 
@@ -160,7 +157,6 @@ e_cal_backend_google_utils_create_cache (ECalBackendGoogle *cbgo)
 	return GINT_TO_POINTER (GNOME_Evolution_Calendar_Success);
 }
 
-
 /**
  * e_cal_backend_google_utils_update:
  *
@@ -172,20 +168,18 @@ e_cal_backend_google_utils_create_cache (ECalBackendGoogle *cbgo)
 gpointer
 e_cal_backend_google_utils_update (gpointer handle)
 {
+	static gint max_results = -1;
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
 	EGoItem *item;
-
 	ECalBackendCache *cache;
-
 	GDataGoogleService *service;
 	static GStaticMutex updating = G_STATIC_MUTEX_INIT;
 	icalcomponent_kind kind;
-
 	GSList *ids_list = NULL, *cache_keys = NULL, *entries_list = NULL;
 	GSList *uid_list = NULL, *iter_list = NULL, *remove = NULL;
 	gboolean needs_to_insert = FALSE;
-	gchar *uri;
+	gchar *uri, *full_uri;
 
 	if (!handle || !E_IS_CAL_BACKEND_GOOGLE (handle)) {
 		g_critical ("\n Invalid handle %s", G_STRLOC);
@@ -202,7 +196,20 @@ e_cal_backend_google_utils_update (gpointer handle)
 	service = e_cal_backend_google_get_service (cbgo);
 	uri = e_cal_backend_google_get_uri (cbgo);
 
-	item->feed = gdata_service_get_feed (GDATA_SERVICE(service), uri, NULL);
+	if (max_results <= 0) {
+		const gchar *env = getenv ("EVO_GOOGLE_MAX_RESULTS");
+
+		if (env)
+			max_results = atoi (env);
+
+		if (max_results <= 0)
+			max_results = 1024;
+	}
+
+	full_uri = g_strdup_printf ("%s?max-results=%d", uri, max_results);
+	item->feed = gdata_service_get_feed (GDATA_SERVICE(service), full_uri, NULL);
+	g_free (full_uri);
+
 	entries_list = gdata_feed_get_entries (item->feed);
 	cache_keys = e_cal_backend_cache_get_keys (cache);
 	kind = e_cal_backend_get_kind (E_CAL_BACKEND (cbgo));
@@ -405,7 +412,7 @@ e_go_item_to_cal_component (EGoItem *item, ECalBackendGoogle *cbgo)
 	ECalComponentDateTime dt;
 	ECalComponentOrganizer *org = NULL;
 	icaltimezone *default_zone;
-	const char *description, *uid, *temp;
+	const gchar *description, *uid, *temp;
 	struct icaltimetype itt;
 	GSList *category_ids;
 	GSList *go_attendee_list = NULL, *l = NULL, *attendee_list = NULL;
@@ -475,7 +482,7 @@ e_go_item_to_cal_component (EGoItem *item, ECalBackendGoogle *cbgo)
 
 	/* Attendees */
 	go_attendee_list = gdata_entry_get_attendee_list (item->entry);
-		
+
 	if (go_attendee_list != NULL) {
 
 		for (l = go_attendee_list; l != NULL; l = l->next) {
@@ -498,25 +505,25 @@ e_go_item_to_cal_component (EGoItem *item, ECalBackendGoogle *cbgo)
 			if (go_attendee->attendee_rel) {
 				gchar *val;
 				val = strstr ((const gchar *)go_attendee->attendee_rel, (const gchar *)"organizer");
-				if (val != NULL && !strcmp ("organizer", val)) {	
-					org = g_new0 (ECalComponentOrganizer, 1);	
+				if (val != NULL && !strcmp ("organizer", val)) {
+					org = g_new0 (ECalComponentOrganizer, 1);
 
-					if (go_attendee->attendee_email) 
+					if (go_attendee->attendee_email)
 						org->value = g_strconcat("MAILTO:", go_attendee->attendee_email, NULL);
-					if (go_attendee->attendee_value) 
+					if (go_attendee->attendee_value)
 						org->cn =  g_strdup (go_attendee->attendee_value);
-				}	
+				}
 			}
-			
-			attendee_list = g_slist_prepend (attendee_list, attendee);	
+
+			attendee_list = g_slist_prepend (attendee_list, attendee);
 		}
 		e_cal_component_set_attendee_list (comp, attendee_list);
 	}
-	
+
 	/* Set the organizer if any */
 	if (org)
 		e_cal_component_set_organizer (comp, org);
-	
+
 	/* Location */
 	e_cal_component_set_location (comp, gdata_entry_get_location (item->entry));
 
@@ -531,13 +538,12 @@ e_go_item_to_cal_component (EGoItem *item, ECalBackendGoogle *cbgo)
 	e_cal_component_set_dtend (comp, &dt);
 
 	uid = gdata_entry_get_id (item->entry);
-	e_cal_component_set_uid (comp, (const char *)uid);
+	e_cal_component_set_uid (comp, (const gchar *)uid);
 	e_cal_component_commit_sequence (comp);
 
 	return comp;
 }
 
-
 /**
  *
  * e_go_item_from_cal_component:
@@ -556,8 +562,8 @@ e_go_item_from_cal_component (ECalBackendGoogle *cbgo, ECalComponent *comp)
 	gchar *temp, *term = NULL;
 	icaltimezone *default_zone;
 	icaltimetype itt;
-	const char *uid;
-	const char *location;
+	const gchar *uid;
+	const gchar *location;
 	GSList *list = NULL;
 	GDataEntry *entry;
 	ECalComponentText *t;
@@ -642,7 +648,6 @@ e_go_item_get_entry (EGoItem *item)
 	return item->entry;
 }
 
-
 /**
  *
  * e_go_item_set_entry:
@@ -682,13 +687,12 @@ gdata_entry_get_entry_by_id (GSList *entries, const gchar *id)
 	return NULL;
 }
 
-
 /***************************************************************** Utility Functions *********************************************/
 
 static gint
 utils_compare_ids (gconstpointer cache_id, gconstpointer modified_cache_id)
 {
-	return strcmp ((char *)cache_id, (char *)modified_cache_id);
+	return strcmp ((gchar *)cache_id, (gchar *)modified_cache_id);
 }
 
 static gchar *
@@ -739,7 +743,6 @@ utils_update_insertion (ECalBackendGoogle *cbgo, ECalBackendCache *cache, EGoIte
 		g_slist_free (entries_list);
 }
 
-
 static void
 utils_update_deletion (ECalBackendGoogle *cbgo, ECalBackendCache *cache, GSList *cache_keys)
 {
@@ -754,13 +757,13 @@ utils_update_deletion (ECalBackendGoogle *cbgo, ECalBackendCache *cache, GSList
 
 	for (list = cache_keys; list; list = g_slist_next (list)) {
 		ECalComponentId *id = NULL;
-		char *comp_str = NULL;
-		comp = e_cal_backend_cache_get_component (cache, (const char *)list->data, NULL);
+		gchar *comp_str = NULL;
+		comp = e_cal_backend_cache_get_component (cache, (const gchar *)list->data, NULL);
 		comp_str = e_cal_component_get_as_string (comp);
 		id = e_cal_component_get_id (comp);
 
 		e_cal_backend_notify_object_removed (E_CAL_BACKEND (cbgo), id, comp_str, NULL);
-		e_cal_backend_cache_remove_component (cache, (const char *) id->uid, id->rid);
+		e_cal_backend_cache_remove_component (cache, (const gchar *) id->uid, id->rid);
 
 		e_cal_component_free_id (id);
 		g_object_unref (comp);
@@ -776,7 +779,7 @@ utils_update_deletion (ECalBackendGoogle *cbgo, ECalBackendCache *cache, GSList
 gchar *
 get_date (ECalComponentDateTime dt)
 {
-	char *temp;
+	gchar *temp;
 	struct icaltimetype itt;
 	struct icaltimetype *itt_u;
 	gchar *month;
@@ -845,7 +848,7 @@ static gboolean
 gd_date_to_ical (EGoItem *item, const gchar *google_time_string, struct icaltimetype *itt, ECalComponentDateTime *dt, icaltimezone *default_zone)
 {
 	gchar *s, *string, *dup;
-	int count = 0;
+	gint count = 0;
 	gboolean is_utc = TRUE;
 
 	g_return_val_if_fail (itt != NULL, FALSE);
@@ -883,7 +886,7 @@ gd_date_to_ical (EGoItem *item, const gchar *google_time_string, struct icaltime
 	*itt = icaltime_from_string (dup);
 
 	if (!is_utc) {
-		const char *zone_name = item->feed ? gdata_feed_get_timezone (item->feed) : NULL;
+		const gchar *zone_name = item->feed ? gdata_feed_get_timezone (item->feed) : NULL;
 
 		if (zone_name) {
 			icaltimezone *zone = icaltimezone_get_builtin_timezone (zone_name);
