@@ -45,9 +45,8 @@
 #include "camel-private.h"
 #include "camel-text-index.h"
 
-
 #define w(x)
-#define io(x) 
+#define io(x)
 #define d(x) /*(printf("%s(%d):%s: ",  __FILE__, __LINE__, __PRETTY_FUNCTION__),(x))*/
 
 /* cursor debug */
@@ -60,7 +59,7 @@
 #define CAMEL_TEXT_INDEX_UNLOCK(kf, lock) \
 	(g_static_rec_mutex_unlock(&((CamelTextIndex *)kf)->priv->lock))
 
-static int text_index_compress_nosync(CamelIndex *idx);
+static gint text_index_compress_nosync(CamelIndex *idx);
 
 /* ********************************************************************** */
 
@@ -73,7 +72,7 @@ struct _CamelTextIndexNamePrivate {
 	EMemPool *pool;
 };
 
-CamelTextIndexName *camel_text_index_name_new(CamelTextIndex *idx, const char *name, camel_key_t nameid);
+CamelTextIndexName *camel_text_index_name_new(CamelTextIndex *idx, const gchar *name, camel_key_t nameid);
 
 /* ****************************** */
 
@@ -83,12 +82,12 @@ struct _CamelTextIndexCursorPrivate {
 	camel_block_t first;
 	camel_block_t next;
 
-	int record_index;
+	gint record_index;
 
-	size_t record_count;
+	gsize record_count;
 	camel_key_t *records;
 
-	char *current;
+	gchar *current;
 };
 
 CamelTextIndexCursor *camel_text_index_cursor_new(CamelTextIndex *idx, camel_block_t data);
@@ -100,9 +99,9 @@ struct _CamelTextIndexKeyCursorPrivate {
 	CamelKeyTable *table;
 
 	camel_key_t keyid;
-	unsigned int flags;
+	guint flags;
 	camel_block_t data;
-	char *current;
+	gchar *current;
 };
 
 CamelTextIndexKeyCursor *camel_text_index_key_cursor_new(CamelTextIndex *idx, CamelKeyTable *table);
@@ -123,8 +122,8 @@ struct _CamelTextIndexPrivate {
 	CamelPartitionTable *name_hash;
 
 	/* Cache of words to write */
-	int word_cache_limit;
-	int word_cache_count;
+	gint word_cache_limit;
+	gint word_cache_count;
 	CamelDList word_cache;
 	GHashTable *words;
 	GStaticRecMutex lock;
@@ -153,8 +152,8 @@ struct _CamelTextIndexWord {
 
 	camel_block_t data;	/* where the data starts */
 	camel_key_t wordid;
-	char *word;
-	unsigned int used;
+	gchar *word;
+	guint used;
 	camel_key_t names[32];
 };
 
@@ -170,7 +169,7 @@ static CamelObjectClass *camel_text_index_parent;
 
 /* call locked */
 static void
-text_index_add_name_to_word(CamelIndex *idx, const char *word, camel_key_t nameid)
+text_index_add_name_to_word(CamelIndex *idx, const gchar *word, camel_key_t nameid)
 {
 	struct _CamelTextIndexWord *w, *wp, *ww;
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
@@ -204,7 +203,7 @@ text_index_add_name_to_word(CamelIndex *idx, const char *word, camel_key_t namei
 				return;
 			}
 		}
-		
+
 		w = g_malloc0(sizeof(*w));
 		w->word = g_strdup(word);
 		w->wordid = wordid;
@@ -253,13 +252,13 @@ text_index_add_name_to_word(CamelIndex *idx, const char *word, camel_key_t namei
 	}
 }
 
-static int
+static gint
 text_index_sync(CamelIndex *idx)
 {
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
 	struct _CamelTextIndexWord *ww;
 	struct _CamelTextIndexRoot *rb;
-	int ret = 0, wfrag, nfrag, work = FALSE;
+	gint ret = 0, wfrag, nfrag, work = FALSE;
 
 	d(printf("sync: blocks = %p\n", p->blocks));
 
@@ -297,7 +296,7 @@ text_index_sync(CamelIndex *idx)
 		g_hash_table_remove(p->words, ww->word);
 		g_free(ww->word);
 		g_free(ww);
-	}	
+	}
 
 	if (camel_key_table_sync(p->word_index) == -1
 	    || camel_key_table_sync(p->name_index) == -1
@@ -323,9 +322,9 @@ text_index_sync(CamelIndex *idx)
 	return ret;
 }
 
-static void tmp_name(const char *in, char *o)
+static void tmp_name(const gchar *in, gchar *o)
 {
-	char *s;
+	gchar *s;
 
 	s = strrchr(in, '/');
 	if (s) {
@@ -337,10 +336,10 @@ static void tmp_name(const char *in, char *o)
 	}
 }
 
-static int
+static gint
 text_index_compress(CamelIndex *idx)
 {
-	int ret;
+	gint ret;
 
 	CAMEL_TEXT_INDEX_LOCK(idx, lock);
 
@@ -354,20 +353,20 @@ text_index_compress(CamelIndex *idx)
 }
 
 /* Attempt to recover index space by compressing the indices */
-static int
+static gint
 text_index_compress_nosync(CamelIndex *idx)
 {
 	CamelTextIndex *newidx;
 	struct _CamelTextIndexPrivate *newp, *oldp;
 	camel_key_t oldkeyid, newkeyid;
 	GHashTable *remap;
-	unsigned int deleted;
+	guint deleted;
 	camel_block_t data, newdata;
-	int i, ret = -1;
-	char *name = NULL;
-	unsigned int flags;
-	char *newpath, *savepath, *oldpath;
-	size_t count, newcount;
+	gint i, ret = -1;
+	gchar *name = NULL;
+	guint flags;
+	gchar *newpath, *savepath, *oldpath;
+	gsize count, newcount;
 	camel_key_t *records, newrecords[256];
 	struct _CamelTextIndexRoot *rb;
 
@@ -425,8 +424,9 @@ text_index_compress_nosync(CamelIndex *idx)
 			rb->names++;
 			camel_partition_table_add(newp->name_hash, name, newkeyid);
 			g_hash_table_insert(remap, GINT_TO_POINTER(oldkeyid), GINT_TO_POINTER(newkeyid));
-		} else
+		} else {
 			io(printf("deleted name '%s'\n", name));
+		}
 		g_free(name);
 		name = NULL;
 		deleted |= flags;
@@ -446,7 +446,7 @@ text_index_compress_nosync(CamelIndex *idx)
 		}
 		while (data) {
 			if (camel_key_file_read(oldp->links, &data, &count, &records) == -1) {
-				io(printf("could not read from old keys at %d for word '%s'\n", (int)data, name));
+				io(printf("could not read from old keys at %d for word '%s'\n", (gint)data, name));
 				goto fail;
 			}
 			for (i=0;i<count;i++) {
@@ -464,7 +464,7 @@ text_index_compress_nosync(CamelIndex *idx)
 			}
 			g_free(records);
 		}
-		
+
 		if (newcount > 0) {
 			if (camel_key_file_write(newp->links, &newdata, newcount, newrecords) == -1)
 				goto fail;
@@ -481,7 +481,7 @@ text_index_compress_nosync(CamelIndex *idx)
 	}
 
 	camel_block_file_touch_block(newp->blocks, newp->blocks->root_block);
-	
+
 	if (camel_index_sync((CamelIndex *)newidx) == -1)
 		goto fail;
 
@@ -493,7 +493,7 @@ text_index_compress_nosync(CamelIndex *idx)
 	/* If this fails, we'll pick up something during restart? */
 	ret = camel_index_rename((CamelIndex *)newidx, oldpath);
 
-#define myswap(a, b) { void *tmp = a; a = b; b = tmp; }
+#define myswap(a, b) { gpointer tmp = a; a = b; b = tmp; }
 	/* Poke the private data across to the new object */
 	/* And change the fd's over, etc? */
 	/* Yes: This is a hack */
@@ -525,11 +525,11 @@ fail:
 	return ret;
 }
 
-static int
+static gint
 text_index_delete(CamelIndex *idx)
 {
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
-	int ret = 0;
+	gint ret = 0;
 
 	if (camel_block_file_delete(p->blocks) == -1)
 		ret = -1;
@@ -539,12 +539,12 @@ text_index_delete(CamelIndex *idx)
 	return ret;
 }
 
-static int
-text_index_rename(CamelIndex *idx, const char *path)
+static gint
+text_index_rename(CamelIndex *idx, const gchar *path)
 {
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
-	char *newlink, *newblock;
-	int err, ret;
+	gchar *newlink, *newblock;
+	gint err, ret;
 
 	CAMEL_TEXT_INDEX_LOCK(idx, lock);
 
@@ -575,8 +575,8 @@ text_index_rename(CamelIndex *idx, const char *path)
 	return 0;
 }
 
-static int
-text_index_has_name(CamelIndex *idx, const char *name)
+static gint
+text_index_has_name(CamelIndex *idx, const gchar *name)
 {
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
 
@@ -584,7 +584,7 @@ text_index_has_name(CamelIndex *idx, const char *name)
 }
 
 static CamelIndexName *
-text_index_add_name(CamelIndex *idx, const char *name)
+text_index_add_name(CamelIndex *idx, const gchar *name)
 {
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
 	camel_key_t keyid;
@@ -608,7 +608,7 @@ text_index_add_name(CamelIndex *idx, const char *name)
 		camel_key_table_set_flags(p->name_index, keyid, 1, 1);
 		camel_partition_table_remove(p->name_hash, name);
 	}
-	
+
 	keyid = camel_key_table_add(p->name_index, name, 0, 0);
 	if (keyid != 0) {
 		camel_partition_table_add(p->name_hash, name, keyid);
@@ -629,14 +629,14 @@ text_index_add_name(CamelIndex *idx, const char *name)
 
 /* call locked */
 static void
-hash_write_word(char *word, void *data, CamelIndexName *idn)
+hash_write_word(gchar *word, gpointer data, CamelIndexName *idn)
 {
 	CamelTextIndexName *tin = (CamelTextIndexName *)idn;
 
 	text_index_add_name_to_word(idn->index, word, tin->priv->nameid);
 }
 
-static int
+static gint
 text_index_write_name(CamelIndex *idx, CamelIndexName *idn)
 {
 	/* force 'flush' of any outstanding data */
@@ -645,9 +645,9 @@ text_index_write_name(CamelIndex *idx, CamelIndexName *idn)
 	/* see text_index_add_name for when this can be 0 */
 	if (((CamelTextIndexName *)idn)->priv->nameid != 0) {
 		CAMEL_TEXT_INDEX_LOCK(idx, lock);
-		
+
 		g_hash_table_foreach(idn->words, (GHFunc)hash_write_word, idn);
-		
+
 		CAMEL_TEXT_INDEX_UNLOCK(idx, lock);
 	}
 
@@ -655,14 +655,14 @@ text_index_write_name(CamelIndex *idx, CamelIndexName *idn)
 }
 
 static CamelIndexCursor *
-text_index_find_name(CamelIndex *idx, const char *name)
+text_index_find_name(CamelIndex *idx, const gchar *name)
 {
 	/* what was this for, umm */
 	return NULL;
 }
 
 static void
-text_index_delete_name(CamelIndex *idx, const char *name)
+text_index_delete_name(CamelIndex *idx, const gchar *name)
 {
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
 	camel_key_t keyid;
@@ -686,12 +686,12 @@ text_index_delete_name(CamelIndex *idx, const char *name)
 }
 
 static CamelIndexCursor *
-text_index_find(CamelIndex *idx, const char *word)
+text_index_find(CamelIndex *idx, const gchar *word)
 {
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
 	camel_key_t keyid;
 	camel_block_t data = 0;
-	unsigned int flags;
+	guint flags;
 	CamelIndexCursor *idc;
 
 	CAMEL_TEXT_INDEX_LOCK(idx, lock);
@@ -763,7 +763,7 @@ camel_text_index_init(CamelTextIndex *idx)
 	/* this cache size and the block cache size have been tuned for about the best
 	   with moderate memory usage.  Doubling the memory usage barely affects performance. */
 	p->word_cache_limit = 4096; /* 1024 = 128K */
-	
+
 	g_static_rec_mutex_init(&p->lock);
 }
 
@@ -792,9 +792,9 @@ camel_text_index_finalise(CamelTextIndex *idx)
 		camel_object_unref((CamelObject *)p->blocks);
 	if (p->links)
 		camel_object_unref((CamelObject *)p->links);
-	
+
 	g_static_rec_mutex_free(&p->lock);
-	
+
 	g_free(p);
 }
 
@@ -802,7 +802,7 @@ CamelType
 camel_text_index_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_index_get_type(), "CamelTextIndex",
 					   sizeof (CamelTextIndex),
@@ -812,14 +812,14 @@ camel_text_index_get_type(void)
 					   (CamelObjectInitFunc) camel_text_index_init,
 					   (CamelObjectFinalizeFunc) camel_text_index_finalise);
 	}
-	
+
 	return type;
 }
 
-static char *
-text_index_normalise(CamelIndex *idx, const char *in, void *data)
+static gchar *
+text_index_normalise(CamelIndex *idx, const gchar *in, gpointer data)
 {
-	char *word;
+	gchar *word;
 
 	/* Sigh, this is really expensive */
 	/*g_utf8_normalize(in, strlen(in), G_NORMALIZE_ALL);*/
@@ -829,12 +829,12 @@ text_index_normalise(CamelIndex *idx, const char *in, void *data)
 }
 
 CamelTextIndex *
-camel_text_index_new(const char *path, int flags)
+camel_text_index_new(const gchar *path, gint flags)
 {
 	CamelTextIndex *idx = (CamelTextIndex *)camel_object_new(camel_text_index_get_type());
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
 	struct _CamelTextIndexRoot *rb;
-	char *link;
+	gchar *link;
 	CamelBlock *bl;
 
 	camel_index_construct((CamelIndex *)idx, path, flags);
@@ -859,7 +859,7 @@ camel_text_index_new(const char *path, int flags)
 		rb->word_index_root = bl->id;
 		camel_block_file_unref_block(p->blocks, bl);
 		camel_block_file_touch_block(p->blocks, p->blocks->root_block);
-	}	
+	}
 
 	if (rb->word_hash_root == 0) {
 		bl = camel_block_file_new_block(p->blocks);
@@ -870,7 +870,7 @@ camel_text_index_new(const char *path, int flags)
 		rb->word_hash_root = bl->id;
 		camel_block_file_unref_block(p->blocks, bl);
 		camel_block_file_touch_block(p->blocks, p->blocks->root_block);
-	}	
+	}
 
 	if (rb->name_index_root == 0) {
 		bl = camel_block_file_new_block(p->blocks);
@@ -881,7 +881,7 @@ camel_text_index_new(const char *path, int flags)
 		rb->name_index_root = bl->id;
 		camel_block_file_unref_block(p->blocks, bl);
 		camel_block_file_touch_block(p->blocks, p->blocks->root_block);
-	}	
+	}
 
 	if (rb->name_hash_root == 0) {
 		bl = camel_block_file_new_block(p->blocks);
@@ -892,7 +892,7 @@ camel_text_index_new(const char *path, int flags)
 		rb->name_hash_root = bl->id;
 		camel_block_file_unref_block(p->blocks, bl);
 		camel_block_file_touch_block(p->blocks, p->blocks->root_block);
-	}	
+	}
 
 	p->word_index = camel_key_table_new(p->blocks, rb->word_index_root);
 	p->word_hash = camel_partition_table_new(p->blocks, rb->word_hash_root);
@@ -913,10 +913,10 @@ fail:
 }
 
 /* returns 0 if the index exists, is valid, and synced, -1 otherwise */
-int
-camel_text_index_check(const char *path)
+gint
+camel_text_index_check(const gchar *path)
 {
-	char *block, *key;
+	gchar *block, *key;
 	CamelBlockFile *blocks;
 	CamelKeyFile *keys;
 
@@ -942,11 +942,11 @@ camel_text_index_check(const char *path)
 	return 0;
 }
 
-int
-camel_text_index_rename(const char *old, const char *new)
+gint
+camel_text_index_rename(const gchar *old, const gchar *new)
 {
-	char *oldname, *newname;
-	int err;
+	gchar *oldname, *newname;
+	gint err;
 
 	/* TODO: camel_text_index_rename should find out if we have an active index and use that instead */
 
@@ -973,11 +973,11 @@ camel_text_index_rename(const char *old, const char *new)
 	return 0;
 }
 
-int
-camel_text_index_remove(const char *old)
+gint
+camel_text_index_remove(const gchar *old)
 {
-	char *block, *key;
-	int ret = 0;
+	gchar *block, *key;
+	gint ret = 0;
 
 	/* TODO: needs to poke any active indices to remain unlinked */
 
@@ -1000,7 +1000,7 @@ camel_text_index_info(CamelTextIndex *idx)
 {
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
 	struct _CamelTextIndexRoot *rb = (struct _CamelTextIndexRoot *)p->blocks->root;
-	int frag;
+	gint frag;
 
 	printf("Path: '%s'\n", idx->parent.path);
 	printf("Version: %u\n", idx->parent.version);
@@ -1027,7 +1027,7 @@ camel_text_index_info(CamelTextIndex *idx)
 enum { KEY_ROOT = 1, KEY_DATA = 2, PARTITION_MAP = 4, PARTITION_DATA = 8 };
 
 static void
-add_type(GHashTable *map, camel_block_t id, int type)
+add_type(GHashTable *map, camel_block_t id, gint type)
 {
 	camel_block_t old;
 
@@ -1045,7 +1045,7 @@ add_partition(GHashTable *map, CamelBlockFile *blocks, camel_block_t id)
 {
 	CamelBlock *bl;
 	CamelPartitionMapBlock *pm;
-	int i;
+	gint i;
 
 	while (id) {
 		add_type(map, id, PARTITION_MAP);
@@ -1103,14 +1103,14 @@ add_keys(GHashTable *map, CamelBlockFile *blocks, camel_block_t id)
 }
 
 static void
-dump_raw(GHashTable *map, char *path)
+dump_raw(GHashTable *map, gchar *path)
 {
-	char buf[1024];
-	char line[256];
-	char *p, c, *e, *a, *o;
-	int v, n, len, i, type;
-	char hex[16] = "0123456789ABCDEF";
-	int fd;
+	gchar buf[1024];
+	gchar line[256];
+	gchar *p, c, *e, *a, *o;
+	gint v, n, len, i, type;
+	gchar hex[16] = "0123456789ABCDEF";
+	gint fd;
 	camel_block_t id, total;
 
 	fd = g_open(path, O_RDONLY|O_BINARY, 0);
@@ -1121,8 +1121,6 @@ dump_raw(GHashTable *map, char *path)
 	while ((len = read(fd, buf, 1024)) == 1024) {
 		id = total;
 
-
-
 		type = g_hash_table_lookup(map, id);
 		switch(type) {
 		case 0:
@@ -1166,7 +1164,6 @@ dump_raw(GHashTable *map, char *path)
 		} break;
 		}
 
-
 		printf("--raw--\n");
 
 		len = 1024;
@@ -1203,9 +1200,9 @@ camel_text_index_dump(CamelTextIndex *idx)
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
 #ifndef DUMP_RAW
 	camel_key_t keyid;
-	char *word;
-	const char *name;
-	unsigned int flags;
+	gchar *word;
+	const gchar *name;
+	guint flags;
 	camel_block_t data;
 
 	/* Iterate over all names in the file first */
@@ -1228,7 +1225,7 @@ camel_text_index_dump(CamelTextIndex *idx)
 		CamelIndexCursor *idc;
 
 		printf("Word: '%s':\n", word);
-		
+
 		idc = camel_index_find((CamelIndex *)idx, word);
 		while ( (name = camel_index_cursor_next(idc)) ) {
 			printf(" %s", name);
@@ -1242,7 +1239,7 @@ camel_text_index_dump(CamelTextIndex *idx)
 	GHashTable *block_type = g_hash_table_new(NULL, NULL);
 	camel_block_t id;
 	struct stat st;
-	int type;
+	gint type;
 
 	add_keys(block_type, p->blocks, p->word_index->rootid);
 	add_keys(block_type, p->blocks, p->name_index->rootid);
@@ -1261,13 +1258,13 @@ camel_text_index_validate(CamelTextIndex *idx)
 {
 	struct _CamelTextIndexPrivate *p = CTI_PRIVATE(idx);
 	camel_key_t keyid;
-	char *word;
-	const char *name;
-	unsigned int flags;
+	gchar *word;
+	const gchar *name;
+	guint flags;
 	camel_block_t data;
-	char *oldword;
+	gchar *oldword;
 	camel_key_t *records;
-	size_t count;
+	gsize count;
 
 	GHashTable *names, *deleted, *words, *keys, *name_word, *word_word;
 
@@ -1345,7 +1342,7 @@ camel_text_index_validate(CamelTextIndex *idx)
 			if (g_hash_table_lookup(used, name) != NULL) {
 				printf("word '%s' uses word '%s' more than once\n", word, name);
 			} else {
-				g_hash_table_insert(used, g_strdup(name), (void *)1);
+				g_hash_table_insert(used, g_strdup(name), (gpointer)1);
 			}
 		}
 		camel_object_unref((CamelObject *)idc);
@@ -1361,7 +1358,7 @@ camel_text_index_validate(CamelTextIndex *idx)
 				printf("Warning, read failed for word '%s', at data '%u'\n", word, data);
 				data = 0;
 			} else {
-				printf("(%d)\n", (int)count);
+				printf("(%d)\n", (gint)count);
 				g_free(records);
 			}
 		}
@@ -1389,12 +1386,12 @@ static CamelIndexNameClass *camel_text_index_name_parent;
 #define CIN_PRIVATE(o) (((CamelTextIndexName *)(o))->priv)
 
 static void
-text_index_name_add_word(CamelIndexName *idn, const char *word)
+text_index_name_add_word(CamelIndexName *idn, const gchar *word)
 {
 	struct _CamelTextIndexNamePrivate *p = ((CamelTextIndexName *)idn)->priv;
 
 	if (g_hash_table_lookup(idn->words, word) == NULL) {
-		char *w = e_mempool_strdup(p->pool, word);
+		gchar *w = e_mempool_strdup(p->pool, word);
 
 		g_hash_table_insert(idn->words, w, w);
 	}
@@ -1405,12 +1402,12 @@ text_index_name_add_word(CamelIndexName *idn, const char *word)
    Used to clean up utf8 before it gets further */
 
 static inline guint32
-camel_utf8_next(const unsigned char **ptr, const unsigned char *ptrend)
+camel_utf8_next(const guchar **ptr, const guchar *ptrend)
 {
-	register unsigned char *p = (unsigned char *)*ptr;
-	register unsigned int c;
+	register guchar *p = (guchar *)*ptr;
+	register guint c;
 	register guint32 v;
-	int l;
+	gint l;
 
 	if (p == ptrend)
 		return 0;
@@ -1435,7 +1432,7 @@ camel_utf8_next(const unsigned char **ptr, const unsigned char *ptrend)
 			v = c & 0x01;
 			l = 5;
 		} else
-			/* Invalid, ignore and look for next start char if room */
+			/* Invalid, ignore and look for next start gchar if room */
 			if (p == ptrend) {
 				return 0;
 			} else {
@@ -1452,26 +1449,26 @@ camel_utf8_next(const unsigned char **ptr, const unsigned char *ptrend)
 			v = (v << 6) | (c & 0x3f);
 		}
 
-		/* valid char */
+		/* valid gchar */
 		if (l == 0) {
 			*ptr = p;
 			return v;
 		}
 
-		/* else look for a start char again */
+		/* else look for a start gchar again */
 	}
 
 	return 0;
 }
 
-static size_t
-text_index_name_add_buffer(CamelIndexName *idn, const char *buffer, size_t len)
+static gsize
+text_index_name_add_buffer(CamelIndexName *idn, const gchar *buffer, gsize len)
 {
 	CamelTextIndexNamePrivate *p = CIN_PRIVATE(idn);
-	const unsigned char *ptr, *ptrend;
+	const guchar *ptr, *ptrend;
 	guint32 c;
-	char utf8[8];
-	int utf8len;
+	gchar utf8[8];
+	gint utf8len;
 
 	if (buffer == NULL) {
 		if (p->buffer->len) {
@@ -1481,8 +1478,8 @@ text_index_name_add_buffer(CamelIndexName *idn, const char *buffer, size_t len)
 		return 0;
 	}
 
-	ptr = (const unsigned char *) buffer;
-	ptrend = (const unsigned char *) buffer+len;
+	ptr = (const guchar *) buffer;
+	ptrend = (const guchar *) buffer+len;
 	while ((c = camel_utf8_next(&ptr, ptrend))) {
 		if (g_unichar_isalnum(c)) {
 			c = g_unichar_tolower(c);
@@ -1494,7 +1491,7 @@ text_index_name_add_buffer(CamelIndexName *idn, const char *buffer, size_t len)
 				text_index_name_add_word(idn, p->buffer->str);
 				/*camel_index_name_add_word(idn, p->buffer->str);*/
 			}
-			
+
 			g_string_truncate (p->buffer, 0);
 		}
 	}
@@ -1529,7 +1526,7 @@ static void
 camel_text_index_name_finalise(CamelTextIndexName *idn)
 {
 	CamelTextIndexNamePrivate *p = CIN_PRIVATE(idn);
-	
+
 	g_hash_table_destroy(idn->parent.words);
 
 	g_string_free(p->buffer, TRUE);
@@ -1542,7 +1539,7 @@ CamelType
 camel_text_index_name_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_index_name_get_type(), "CamelTextIndexName",
 					   sizeof (CamelTextIndexName),
@@ -1552,12 +1549,12 @@ camel_text_index_name_get_type(void)
 					   (CamelObjectInitFunc) camel_text_index_name_init,
 					   (CamelObjectFinalizeFunc) camel_text_index_name_finalise);
 	}
-	
+
 	return type;
 }
 
 CamelTextIndexName *
-camel_text_index_name_new(CamelTextIndex *idx, const char *name, camel_key_t nameid)
+camel_text_index_name_new(CamelTextIndex *idx, const gchar *name, camel_key_t nameid)
 {
 	CamelTextIndexName *idn = (CamelTextIndexName *)camel_object_new(camel_text_index_name_get_type());
 	CamelIndexName *cin = &idn->parent;
@@ -1580,12 +1577,12 @@ static CamelIndexCursorClass *camel_text_index_cursor_parent;
 #define CIC_CLASS(o) ((CamelTextIndexCursorClass *)(((CamelObject *)o)->classfuncs))
 #define CIC_PRIVATE(o) (((CamelTextIndexCursor *)(o))->priv)
 
-static const char *
+static const gchar *
 text_index_cursor_next(CamelIndexCursor *idc)
 {
 	struct _CamelTextIndexCursorPrivate *p = CIC_PRIVATE(idc);
 	struct _CamelTextIndexPrivate *tip = CTI_PRIVATE(idc->index);
-	unsigned int flags;
+	guint flags;
 
 	c(printf("Going to next cursor for word with data '%08x' next %08x\n", p->first, p->next));
 
@@ -1606,7 +1603,7 @@ text_index_cursor_next(CamelIndexCursor *idc)
 		if (flags & 1) {
 			g_free(p->current);
 			p->current = NULL;
-		}		
+		}
 		p->record_index++;
 	} while (p->current == NULL);
 
@@ -1658,7 +1655,7 @@ CamelType
 camel_text_index_cursor_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_index_cursor_get_type(), "CamelTextIndexCursor",
 					   sizeof (CamelTextIndexCursor),
@@ -1668,7 +1665,7 @@ camel_text_index_cursor_get_type(void)
 					   (CamelObjectInitFunc) camel_text_index_cursor_init,
 					   (CamelObjectFinalizeFunc) camel_text_index_cursor_finalise);
 	}
-	
+
 	return type;
 }
 
@@ -1698,7 +1695,7 @@ static CamelIndexCursorClass *camel_text_index_key_cursor_parent;
 #define CIKC_CLASS(o) ((CamelTextIndexKeyCursorClass *)(((CamelObject *)o)->classfuncs))
 #define CIKC_PRIVATE(o) (((CamelTextIndexKeyCursor *)(o))->priv)
 
-static const char *
+static const gchar *
 text_index_key_cursor_next(CamelIndexCursor *idc)
 {
 	struct _CamelTextIndexKeyCursorPrivate *p = CIKC_PRIVATE(idc);
@@ -1770,7 +1767,7 @@ CamelType
 camel_text_index_key_cursor_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_index_cursor_get_type(), "CamelTextIndexKeyCursor",
 					   sizeof (CamelTextIndexKeyCursor),
@@ -1780,7 +1777,7 @@ camel_text_index_key_cursor_get_type(void)
 					   (CamelObjectInitFunc) camel_text_index_key_cursor_init,
 					   (CamelObjectFinalizeFunc) camel_text_index_key_cursor_finalise);
 	}
-	
+
 	return type;
 }
 
@@ -1815,12 +1812,12 @@ struct _CamelIndexRoot {
 	camel_block_t name_hash_root;
 };
 
-char wordbuffer[] = "This is a buffer of multiple words.  Some of the words are duplicates"
+gchar wordbuffer[] = "This is a buffer of multiple words.  Some of the words are duplicates"
 " while other words are the same, some are in difFerenT Different different case cAsE casE,"
 " with,with:with;with-with'with\"'\"various punctuation as well.  So much for those Words. and 10"
 " numbers in a row too 1,2,3,4,5,6,7,8,9,10!  Yay!.";
 
-int main(int argc, char **argv)
+gint main(gint argc, gchar **argv)
 {
 #if 0
 	CamelBlockFile *bs;
@@ -1829,15 +1826,15 @@ int main(int argc, char **argv)
 	CamelBlock *keyroot, *partroot;
 	struct _CamelIndexRoot *root;
 	FILE *fp;
-	char line[256], *key;
+	gchar line[256], *key;
 	camel_key_t keyid;
-	int index = 0, flags, data;
+	gint index = 0, flags, data;
 #endif
 	CamelIndex *idx;
 	CamelIndexName *idn;
 	CamelIndexCursor *idc;
-	const char *word;
-	int i;
+	const gchar *word;
+	gint i;
 
 	printf("Camel text index tester!\n");
 
@@ -1846,7 +1843,6 @@ int main(int argc, char **argv)
 
 	idx = (CamelIndex *)camel_text_index_new("textindex", O_CREAT|O_RDWR|O_TRUNC);
 
-
 #if 1
 	camel_index_compress(idx);
 
@@ -1854,7 +1850,7 @@ int main(int argc, char **argv)
 #endif
 
 	for (i=0;i<100;i++) {
-		char name[16];
+		gchar name[16];
 
 		sprintf(name, "%d", i);
 		printf("Adding words to name '%s'\n", name);
@@ -1911,7 +1907,7 @@ int main(int argc, char **argv)
 		line[strlen(line)-1] = 0;
 
 		/* see if its already there */
-		keyid = camel_partition_table_lookup(cpi, line);		
+		keyid = camel_partition_table_lookup(cpi, line);
 		if (keyid == 0) {
 			m(printf("Adding word '%s' %d\n", line, index));
 
@@ -1921,7 +1917,7 @@ int main(int argc, char **argv)
 			camel_partition_table_add(cpi, line, keyid);
 
 			m(printf("Lookup word '%s'\n", line));
-			keyid = camel_partition_table_lookup(cpi, line);		
+			keyid = camel_partition_table_lookup(cpi, line);
 			m(printf(" key = %08x\n", keyid));
 		}
 
@@ -1945,7 +1941,7 @@ int main(int argc, char **argv)
 	while (fgets(line, sizeof(line), fp) != NULL) {
 		line[strlen(line)-1] = 0;
 		m(printf("Lookup word '%s' %d\n", line, index));
-		keyid = camel_partition_table_lookup(cpi, line);		
+		keyid = camel_partition_table_lookup(cpi, line);
 		m(printf(" key = %08d\n", keyid));
 
 		m(printf("Lookup key %08x\n", keyid));
