@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2002 Ximian Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
@@ -29,9 +29,6 @@
 #include <string.h>
 #include <unistd.h>
 
-#include <libedataserver/md5-utils.h>
-#include <libedataserver/e-memory.h>
-
 #include "camel-file-utils.h"
 #include "camel-private.h"
 #include "camel-store.h"
@@ -50,16 +47,16 @@
 
 static void namespace_clear(CamelStoreSummary *s);
 
-static int summary_header_load(CamelStoreSummary *, FILE *);
-static int summary_header_save(CamelStoreSummary *, FILE *);
+static gint summary_header_load(CamelStoreSummary *, FILE *);
+static gint summary_header_save(CamelStoreSummary *, FILE *);
 
-/*static CamelStoreInfo * store_info_new(CamelStoreSummary *, const char *);*/
+/*static CamelStoreInfo * store_info_new(CamelStoreSummary *, const gchar *);*/
 static CamelStoreInfo * store_info_load(CamelStoreSummary *, FILE *);
-static int		 store_info_save(CamelStoreSummary *, FILE *, CamelStoreInfo *);
+static gint		 store_info_save(CamelStoreSummary *, FILE *, CamelStoreInfo *);
 static void		 store_info_free(CamelStoreSummary *, CamelStoreInfo *);
 
-static const char *store_info_string(CamelStoreSummary *, const CamelStoreInfo *, int);
-static void store_info_set_string(CamelStoreSummary *, CamelStoreInfo *, int, const char *);
+static const gchar *store_info_string(CamelStoreSummary *, const CamelStoreInfo *, gint);
+static void store_info_set_string(CamelStoreSummary *, CamelStoreInfo *, int, const gchar *);
 
 static void camel_imap_store_summary_class_init (CamelImapStoreSummaryClass *klass);
 static void camel_imap_store_summary_init       (CamelImapStoreSummary *obj);
@@ -142,7 +139,7 @@ camel_imap_store_summary_new (void)
 /**
  * camel_imap_store_summary_full_name:
  * @s:
- * @path:
+ * @full_name:
  *
  * Retrieve a summary item by full name.
  *
@@ -154,9 +151,9 @@ camel_imap_store_summary_new (void)
  * It must be freed using camel_store_summary_info_free().
  **/
 CamelImapStoreInfo *
-camel_imap_store_summary_full_name(CamelImapStoreSummary *s, const char *full_name)
+camel_imap_store_summary_full_name(CamelImapStoreSummary *s, const gchar *full_name)
 {
-	int count, i;
+	gint count, i;
 	CamelImapStoreInfo *info;
 
 	count = camel_store_summary_count((CamelStoreSummary *)s);
@@ -172,12 +169,12 @@ camel_imap_store_summary_full_name(CamelImapStoreSummary *s, const char *full_na
 	return NULL;
 }
 
-char *
-camel_imap_store_summary_full_to_path(CamelImapStoreSummary *s, const char *full_name, char dir_sep)
+gchar *
+camel_imap_store_summary_full_to_path(CamelImapStoreSummary *s, const gchar *full_name, gchar dir_sep)
 {
-	char *path, *p;
-	int c;
-	const char *f;
+	gchar *path, *p;
+	gint c;
+	const gchar *f;
 
 	if (dir_sep != '/') {
 		p = path = alloca(strlen(full_name)*3+1);
@@ -192,7 +189,7 @@ camel_imap_store_summary_full_to_path(CamelImapStoreSummary *s, const char *full
 		}
 		*p = 0;
 	} else
-		path = (char *)full_name;
+		path = (gchar *)full_name;
 
 	return g_strdup(path);
 }
@@ -207,14 +204,14 @@ static guint32 hexnib(guint32 c)
 		return 0;
 }
 
-char *
-camel_imap_store_summary_path_to_full(CamelImapStoreSummary *s, const char *path, char dir_sep)
+gchar *
+camel_imap_store_summary_path_to_full(CamelImapStoreSummary *s, const gchar *path, gchar dir_sep)
 {
-	char *full, *f;
+	gchar *full, *f;
 	guint32 c, v = 0;
-	const char *p;
-	int state=0;
-	char *subpath, *last = NULL;
+	const gchar *p;
+	gint state=0;
+	gchar *subpath, *last = NULL;
 	CamelStoreInfo *si;
 	CamelImapStoreNamespace *ns;
 
@@ -247,7 +244,7 @@ camel_imap_store_summary_path_to_full(CamelImapStoreSummary *s, const char *path
 	else
 		p = path;
 
-	while ((c = camel_utf8_getc((const unsigned char **)&p))) {
+	while ((c = camel_utf8_getc((const guchar **)&p))) {
 		switch(state) {
 		case 0:
 			if (c == '%')
@@ -255,7 +252,7 @@ camel_imap_store_summary_path_to_full(CamelImapStoreSummary *s, const char *path
 			else {
 				if (c == '/')
 					c = dir_sep;
-				camel_utf8_putc((unsigned char **) &f, c);
+				camel_utf8_putc((guchar **) &f, c);
 			}
 			break;
 		case 1:
@@ -265,11 +262,11 @@ camel_imap_store_summary_path_to_full(CamelImapStoreSummary *s, const char *path
 		case 2:
 			state = 0;
 			v |= hexnib(c);
-			camel_utf8_putc((unsigned char **) &f, v);
+			camel_utf8_putc((guchar **) &f, v);
 			break;
 		}
 	}
-	camel_utf8_putc((unsigned char **) &f, c);
+	camel_utf8_putc((guchar **) &f, c);
 
 	/* merge old path part if required */
 	f = g_strdup(full);
@@ -288,12 +285,12 @@ camel_imap_store_summary_path_to_full(CamelImapStoreSummary *s, const char *path
 }
 
 CamelImapStoreInfo *
-camel_imap_store_summary_add_from_full(CamelImapStoreSummary *s, const char *full, char dir_sep)
+camel_imap_store_summary_add_from_full(CamelImapStoreSummary *s, const gchar *full, gchar dir_sep)
 {
 	CamelImapStoreInfo *info;
-	char *pathu8, *prefix;
-	int len;
-	char *full_name;
+	gchar *pathu8, *prefix;
+	gint len;
+	gchar *full_name;
 	CamelImapStoreNamespace *ns;
 
 	d(printf("adding full name '%s' '%c'\n", full, dir_sep));
@@ -340,21 +337,22 @@ camel_imap_store_summary_add_from_full(CamelImapStoreSummary *s, const char *ful
 		d(printf("  '%s' -> '%s'\n", pathu8, full_name));
 		camel_store_info_set_string((CamelStoreSummary *)s, (CamelStoreInfo *)info, CAMEL_IMAP_STORE_INFO_FULL_NAME, full_name);
 
-		if (g_ascii_strcasecmp(full_name, "inbox"))
+		if (!g_ascii_strcasecmp(full_name, "inbox"))
 			info->info.flags |= CAMEL_FOLDER_SYSTEM|CAMEL_FOLDER_TYPE_INBOX;
-	} else
+	} else {
 		d(printf("  failed\n"));
+	}
 
 	return info;
 }
 
 /* should this be const? */
 /* TODO: deprecate/merge this function with path_to_full */
-char *
-camel_imap_store_summary_full_from_path(CamelImapStoreSummary *s, const char *path)
+gchar *
+camel_imap_store_summary_full_from_path(CamelImapStoreSummary *s, const gchar *path)
 {
 	CamelImapStoreNamespace *ns;
-	char *name = NULL;
+	gchar *name = NULL;
 
 	ns = camel_imap_store_summary_namespace_find_path(s, path);
 	if (ns)
@@ -366,11 +364,11 @@ camel_imap_store_summary_full_from_path(CamelImapStoreSummary *s, const char *pa
 }
 
 /* TODO: this api needs some more work */
-CamelImapStoreNamespace *camel_imap_store_summary_namespace_new(CamelImapStoreSummary *s, const char *full_name, char dir_sep)
+CamelImapStoreNamespace *camel_imap_store_summary_namespace_new(CamelImapStoreSummary *s, const gchar *full_name, gchar dir_sep)
 {
 	CamelImapStoreNamespace *ns;
-	char *p, *o, c;
-	int len;
+	gchar *p, *o, c;
+	gint len;
 
 	ns = g_malloc0(sizeof(*ns));
 	ns->full_name = g_strdup(full_name);
@@ -401,9 +399,9 @@ void camel_imap_store_summary_namespace_set(CamelImapStoreSummary *s, CamelImapS
 }
 
 CamelImapStoreNamespace *
-camel_imap_store_summary_namespace_find_path(CamelImapStoreSummary *s, const char *path)
+camel_imap_store_summary_namespace_find_path(CamelImapStoreSummary *s, const gchar *path)
 {
-	int len;
+	gint len;
 	CamelImapStoreNamespace *ns;
 
 	/* NB: this currently only compares against 1 namespace, in future compare against others */
@@ -422,9 +420,9 @@ camel_imap_store_summary_namespace_find_path(CamelImapStoreSummary *s, const cha
 }
 
 CamelImapStoreNamespace *
-camel_imap_store_summary_namespace_find_full(CamelImapStoreSummary *s, const char *full)
+camel_imap_store_summary_namespace_find_full(CamelImapStoreSummary *s, const gchar *full)
 {
-	int len;
+	gint len;
 	CamelImapStoreNamespace *ns;
 
 	/* NB: this currently only compares against 1 namespace, in future compare against others */
@@ -480,7 +478,7 @@ namespace_load(CamelStoreSummary *s, FILE *in)
 	return ns;
 }
 
-static int
+static gint
 namespace_save(CamelStoreSummary *s, FILE *in, CamelImapStoreNamespace *ns)
 {
 	if (camel_file_util_encode_string(in, ns->path) == -1
@@ -491,7 +489,7 @@ namespace_save(CamelStoreSummary *s, FILE *in, CamelImapStoreNamespace *ns)
 	return 0;
 }
 
-static int
+static gint
 summary_header_load(CamelStoreSummary *s, FILE *in)
 {
 	CamelImapStoreSummary *is = (CamelImapStoreSummary *)s;
@@ -525,7 +523,7 @@ summary_header_load(CamelStoreSummary *s, FILE *in)
 	return 0;
 }
 
-static int
+static gint
 summary_header_save(CamelStoreSummary *s, FILE *out)
 {
 	CamelImapStoreSummary *is = (CamelImapStoreSummary *)s;
@@ -566,7 +564,7 @@ store_info_load(CamelStoreSummary *s, FILE *in)
 	return (CamelStoreInfo *)mi;
 }
 
-static int
+static gint
 store_info_save(CamelStoreSummary *s, FILE *out, CamelStoreInfo *mi)
 {
 	CamelImapStoreInfo *isi = (CamelImapStoreInfo *)mi;
@@ -587,8 +585,8 @@ store_info_free(CamelStoreSummary *s, CamelStoreInfo *mi)
 	camel_imap_store_summary_parent->store_info_free(s, mi);
 }
 
-static const char *
-store_info_string(CamelStoreSummary *s, const CamelStoreInfo *mi, int type)
+static const gchar *
+store_info_string(CamelStoreSummary *s, const CamelStoreInfo *mi, gint type)
 {
 	CamelImapStoreInfo *isi = (CamelImapStoreInfo *)mi;
 
@@ -605,7 +603,7 @@ store_info_string(CamelStoreSummary *s, const CamelStoreInfo *mi, int type)
 }
 
 static void
-store_info_set_string(CamelStoreSummary *s, CamelStoreInfo *mi, int type, const char *str)
+store_info_set_string(CamelStoreSummary *s, CamelStoreInfo *mi, gint type, const gchar *str)
 {
 	CamelImapStoreInfo *isi = (CamelImapStoreInfo *)mi;
 
