@@ -6,7 +6,7 @@
  *   Dan Winship <danw@ximian.com>
  *   Michael Zucchi <notzed@ximian.com>
  *
- * Copyright (C) 2002 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -52,8 +52,9 @@ static void pop3_refresh_info (CamelFolder *folder, CamelException *ex);
 static void pop3_sync (CamelFolder *folder, gboolean expunge, CamelException *ex);
 static gint pop3_get_message_count (CamelFolder *folder);
 static GPtrArray *pop3_get_uids (CamelFolder *folder);
-static CamelMimeMessage *pop3_get_message (CamelFolder *folder, const char *uid, CamelException *ex);
-static gboolean pop3_set_message_flags (CamelFolder *folder, const char *uid, guint32 flags, guint32 set);
+static CamelMimeMessage *pop3_get_message (CamelFolder *folder, const gchar *uid, CamelException *ex);
+static gboolean pop3_set_message_flags (CamelFolder *folder, const gchar *uid, guint32 flags, guint32 set);
+static gchar * pop3_get_filename (CamelFolder *folder, const gchar *uid, CamelException *ex);
 
 static void
 camel_pop3_folder_class_init (CamelPOP3FolderClass *camel_pop3_folder_class)
@@ -69,6 +70,7 @@ camel_pop3_folder_class_init (CamelPOP3FolderClass *camel_pop3_folder_class)
 	camel_folder_class->get_message_count = pop3_get_message_count;
 	camel_folder_class->get_uids = pop3_get_uids;
 	camel_folder_class->free_uids = camel_folder_free_shallow;
+	camel_folder_class->get_filename = pop3_get_filename;
 
 	camel_folder_class->get_message = pop3_get_message;
 	camel_folder_class->set_message_flags = pop3_set_message_flags;
@@ -98,7 +100,7 @@ pop3_finalize (CamelObject *object)
 	CamelPOP3Folder *pop3_folder = CAMEL_POP3_FOLDER (object);
 	CamelPOP3FolderInfo **fi = (CamelPOP3FolderInfo **)pop3_folder->uids->pdata;
 	CamelPOP3Store *pop3_store = (CamelPOP3Store *)((CamelFolder *)pop3_folder)->parent_store;
-	int i;
+	gint i;
 
 	if (pop3_folder->uids) {
 		for (i=0;i<pop3_folder->uids->len;i++,fi++) {
@@ -139,7 +141,7 @@ camel_pop3_folder_new (CamelStore *parent, CamelException *ex)
 
 /* create a uid from md5 of 'top' output */
 static void
-cmd_builduid(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
+cmd_builduid(CamelPOP3Engine *pe, CamelPOP3Stream *stream, gpointer data)
 {
 	GChecksum *checksum;
 	CamelPOP3FolderInfo *fi = data;
@@ -184,11 +186,11 @@ cmd_builduid(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 }
 
 static void
-cmd_list(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
+cmd_list(CamelPOP3Engine *pe, CamelPOP3Stream *stream, gpointer data)
 {
-	int ret;
-	unsigned int len, id, size;
-	unsigned char *line;
+	gint ret;
+	guint len, id, size;
+	guchar *line;
 	CamelFolder *folder = data;
 	CamelPOP3Store *pop3_store = CAMEL_POP3_STORE (folder->parent_store);
 	CamelPOP3FolderInfo *fi;
@@ -196,7 +198,7 @@ cmd_list(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 	do {
 		ret = camel_pop3_stream_line(stream, &line, &len);
 		if (ret>=0) {
-			if (sscanf((char *) line, "%u %u", &id, &size) == 2) {
+			if (sscanf((gchar *) line, "%u %u", &id, &size) == 2) {
 				fi = g_malloc0(sizeof(*fi));
 				fi->size = size;
 				fi->id = id;
@@ -211,22 +213,22 @@ cmd_list(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 }
 
 static void
-cmd_uidl(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
+cmd_uidl(CamelPOP3Engine *pe, CamelPOP3Stream *stream, gpointer data)
 {
-	int ret;
-	unsigned int len;
-	unsigned char *line;
-	char uid[1025];
-	unsigned int id;
+	gint ret;
+	guint len;
+	guchar *line;
+	gchar uid[1025];
+	guint id;
 	CamelPOP3FolderInfo *fi;
 	CamelPOP3Folder *folder = data;
 
 	do {
 		ret = camel_pop3_stream_line(stream, &line, &len);
 		if (ret>=0) {
-			if (strlen((char *) line) > 1024)
+			if (strlen((gchar *) line) > 1024)
 				line[1024] = 0;
-			if (sscanf((char *) line, "%u %s", &id, uid) == 2) {
+			if (sscanf((gchar *) line, "%u %s", &id, uid) == 2) {
 				fi = g_hash_table_lookup(folder->uids_id, GINT_TO_POINTER(id));
 				if (fi) {
 					camel_operation_progress(NULL, (fi->index+1) * 100 / folder->uids->len);
@@ -246,7 +248,7 @@ pop3_refresh_info (CamelFolder *folder, CamelException *ex)
 	CamelPOP3Store *pop3_store = CAMEL_POP3_STORE (folder->parent_store);
 	CamelPOP3Folder *pop3_folder = (CamelPOP3Folder *) folder;
 	CamelPOP3Command *pcl, *pcu = NULL;
-	int i;
+	gint i;
 
 	camel_operation_start (NULL, _("Retrieving POP summary"));
 
@@ -300,7 +302,7 @@ pop3_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 {
 	CamelPOP3Folder *pop3_folder;
 	CamelPOP3Store *pop3_store;
-	int i;
+	gint i;
 	CamelPOP3FolderInfo *fi;
 
 	pop3_folder = CAMEL_POP3_FOLDER (folder);
@@ -361,11 +363,11 @@ pop3_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 }
 
 static gboolean
-pop3_get_message_time_from_cache (CamelFolder *folder, const char *uid, time_t *message_time)
+pop3_get_message_time_from_cache (CamelFolder *folder, const gchar *uid, time_t *message_time)
 {
 	CamelPOP3Store *pop3_store;
 	CamelStream *stream = NULL;
-	char buffer[1];
+	gchar buffer[1];
 	gboolean res = FALSE;
 
 	g_return_val_if_fail (folder != NULL, FALSE);
@@ -381,8 +383,6 @@ pop3_get_message_time_from_cache (CamelFolder *folder, const char *uid, time_t *
 	    && buffer[0] == '#') {
 		CamelMimeMessage *message;
 
-		camel_object_ref ((CamelObject *)stream);
-
 		message = camel_mime_message_new ();
 		if (camel_data_wrapper_construct_from_stream ((CamelDataWrapper *)message, stream) == -1) {
 			g_warning (_("Cannot get message %s: %s"), uid, g_strerror (errno));
@@ -396,19 +396,20 @@ pop3_get_message_time_from_cache (CamelFolder *folder, const char *uid, time_t *
 
 			camel_object_unref ((CamelObject *)message);
 		}
-
-		camel_object_unref ((CamelObject *)stream);
 	}
 
+	if (stream) {
+		camel_object_unref (stream);
+	}
 	return res;
 }
 
-int
-camel_pop3_delete_old(CamelFolder *folder, int days_to_delete,	CamelException *ex)
+gint
+camel_pop3_delete_old(CamelFolder *folder, gint days_to_delete,	CamelException *ex)
 {
 	CamelPOP3Folder *pop3_folder;
 	CamelPOP3FolderInfo *fi;
-	int i;
+	gint i;
 	CamelPOP3Store *pop3_store;
 	time_t temp, message_time;
 
@@ -422,8 +423,8 @@ camel_pop3_delete_old(CamelFolder *folder, int days_to_delete,	CamelException *e
 
 		d(printf("%s(%d): fi->uid=[%s]\n", __FILE__, __LINE__, fi->uid));
 		if (pop3_get_message_time_from_cache (folder, fi->uid, &message_time)) {
-			double time_diff = difftime(temp,message_time);
-			int day_lag = time_diff/(60*60*24);
+			gdouble time_diff = difftime(temp,message_time);
+			gint day_lag = time_diff/(60*60*24);
 
 			d(printf("%s(%d): message_time= [%ld]\n", __FILE__, __LINE__, message_time));
 			d(printf("%s(%d): day_lag=[%d] \t days_to_delete=[%d]\n",
@@ -474,11 +475,11 @@ camel_pop3_delete_old(CamelFolder *folder, int days_to_delete,	CamelException *e
 }
 
 static void
-cmd_tocache(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
+cmd_tocache(CamelPOP3Engine *pe, CamelPOP3Stream *stream, gpointer data)
 {
 	CamelPOP3FolderInfo *fi = data;
-	char buffer[2048];
-	int w = 0, n;
+	gchar buffer[2048];
+	gint w = 0, n;
 
 	/* What if it fails? */
 
@@ -507,7 +508,7 @@ cmd_tocache(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 done:
 	if (n == -1) {
 		fi->err = errno;
-		g_warning("POP3 retrieval failed: %s", strerror(errno));
+		g_warning("POP3 retrieval failed: %s", g_strerror(errno));
 	} else {
 		fi->err = 0;
 	}
@@ -516,16 +517,33 @@ done:
 	fi->stream = NULL;
 }
 
+static gchar *
+pop3_get_filename (CamelFolder *folder, const gchar *uid, CamelException *ex)
+{
+	CamelPOP3Folder *pop3_folder = (CamelPOP3Folder *)folder;
+	CamelPOP3Store *pop3_store = (CamelPOP3Store *)((CamelFolder *)pop3_folder)->parent_store;
+	CamelPOP3FolderInfo *fi;
+
+	fi = g_hash_table_lookup(pop3_folder->uids_uid, uid);
+	if (fi == NULL) {
+		camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID_UID,
+				      _("No message with UID %s"), uid);
+		return NULL;
+	}
+
+	return camel_data_cache_get_filename (pop3_store->cache, "cache", fi->uid, NULL);
+}
+
 static CamelMimeMessage *
-pop3_get_message (CamelFolder *folder, const char *uid, CamelException *ex)
+pop3_get_message (CamelFolder *folder, const gchar *uid, CamelException *ex)
 {
 	CamelMimeMessage *message = NULL;
 	CamelPOP3Store *pop3_store = CAMEL_POP3_STORE (folder->parent_store);
 	CamelPOP3Folder *pop3_folder = (CamelPOP3Folder *)folder;
 	CamelPOP3Command *pcr;
 	CamelPOP3FolderInfo *fi;
-	char buffer[1];
-	int i, last;
+	gchar buffer[1];
+	gint i, last;
 	CamelStream *stream = NULL;
 
 	fi = g_hash_table_lookup(pop3_folder->uids_uid, uid);
@@ -653,7 +671,7 @@ fail:
 }
 
 static gboolean
-pop3_set_message_flags (CamelFolder *folder, const char *uid, guint32 flags, guint32 set)
+pop3_set_message_flags (CamelFolder *folder, const gchar *uid, guint32 flags, guint32 set)
 {
 	CamelPOP3Folder *pop3_folder = CAMEL_POP3_FOLDER (folder);
 	CamelPOP3FolderInfo *fi;
@@ -686,7 +704,7 @@ pop3_get_uids (CamelFolder *folder)
 	CamelPOP3Folder *pop3_folder = CAMEL_POP3_FOLDER (folder);
 	GPtrArray *uids = g_ptr_array_new();
 	CamelPOP3FolderInfo **fi = (CamelPOP3FolderInfo **)pop3_folder->uids->pdata;
-	int i;
+	gint i;
 
 	for (i=0;i<pop3_folder->uids->len;i++,fi++) {
 		if (fi[0]->uid)
