@@ -47,8 +47,6 @@ static GType        e_destination_store_get_column_type (GtkTreeModel       *tre
 static gboolean     e_destination_store_get_iter        (GtkTreeModel       *tree_model,
 							 GtkTreeIter        *iter,
 							 GtkTreePath        *path);
-GtkTreePath *e_destination_store_get_path        (GtkTreeModel       *tree_model,
-							 GtkTreeIter        *iter);
 static void         e_destination_store_get_value       (GtkTreeModel       *tree_model,
 							 GtkTreeIter        *iter,
 							 gint                column,
@@ -259,11 +257,11 @@ static gint
 find_destination_by_email (EDestinationStore *destination_store, EDestination *destination)
 {
 	gint i;
-	const char *e_mail = e_destination_get_email (destination);
+	const gchar *e_mail = e_destination_get_email (destination);
 
 	for (i = 0; i < destination_store->destinations->len; i++) {
 		EDestination *destination_here = g_ptr_array_index (destination_store->destinations, i);
-		const char *mail = e_destination_get_email (destination_here);
+		const gchar *mail = e_destination_get_email (destination_here);
 
 		if (g_str_equal (e_mail, mail))
 			return i;
@@ -450,7 +448,7 @@ e_destination_store_remove_destination (EDestinationStore *destination_store, ED
 }
 
 void
-e_destination_store_remove_destination_nth (EDestinationStore *destination_store, int n)
+e_destination_store_remove_destination_nth (EDestinationStore *destination_store, gint n)
 {
 	EDestination *destination;
 
@@ -641,7 +639,7 @@ e_destination_store_get_value (GtkTreeModel *tree_model,
 	EDestinationStore *destination_store = E_DESTINATION_STORE (tree_model);
 	EDestination      *destination;
 	const gchar       *string;
-	GString 	  *string_new;
+	GString	  *string_new;
 	gint               row;
 	EContact	  *contact;
 
