@@ -8,10 +8,7 @@
 #include "e2k-security-descriptor.h"
 #include <gtk/gtk.h>
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define EXCHANGE_TYPE_FOLDER_SIZE			(exchange_folder_size_get_type ())
 #define EXCHANGE_FOLDER_SIZE(obj)			(G_TYPE_CHECK_INSTANCE_CAST ((obj), EXCHANGE_TYPE_FOLDER_SIZE, ExchangeFolderSize))
@@ -19,7 +16,6 @@ extern "C" {
 #define EXCHANGE_IS_FOLDER_SIZE(obj)			(G_TYPE_CHECK_INSTANCE_TYPE ((obj), EXCHANGE_TYPE_FOLDER_SIZE))
 #define EXCHANGE_IS_FOLDER_SIZE_CLASS(klass)		(G_TYPE_CHECK_CLASS_TYPE ((obj), EXCHANGE_TYPE_FOLDER_SIZE))
 
-
 typedef struct _ExchangeFolderSize        ExchangeFolderSize;
 typedef struct _ExchangeFolderSizePrivate ExchangeFolderSizePrivate;
 typedef struct _ExchangeFolderSizeClass   ExchangeFolderSizeClass;
@@ -40,16 +36,14 @@ GType    exchange_folder_size_get_type (void);
 ExchangeFolderSize *exchange_folder_size_new (void);
 
 void exchange_folder_size_update (ExchangeFolderSize *fsize,
-						const char *folder_name,
+						const gchar *folder_name,
 						gdouble folder_size);
-void exchange_folder_size_remove (ExchangeFolderSize *fsize, const char *folder_name);
+void exchange_folder_size_remove (ExchangeFolderSize *fsize, const gchar *folder_name);
 
-gdouble exchange_folder_size_get (ExchangeFolderSize *fsize, const char *folder_name);
+gdouble exchange_folder_size_get (ExchangeFolderSize *fsize, const gchar *folder_name);
 
 GtkListStore *exchange_folder_size_get_model (ExchangeFolderSize *fsize);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __EXCHANGE_FOLDER_SIZE_H__ */
