@@ -4,7 +4,7 @@
  *  JP Rosevear <jpr@ximian.com>
  *  Rodrigo Moya <rodrigo@ximian.com>
  *
- * Copyright 2003, Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -53,7 +53,7 @@ e_gw_sendoptions_get_general_options (EGwSendOptions *opts)
 }
 
 EGwSendOptionsStatusTracking*
-e_gw_sendoptions_get_status_tracking_options (EGwSendOptions *opts, char *type)
+e_gw_sendoptions_get_status_tracking_options (EGwSendOptions *opts, const gchar *type)
 {
 	g_return_val_if_fail (opts != NULL || E_IS_GW_SENDOPTIONS (opts), NULL);
 	g_return_val_if_fail (type != NULL, NULL);
@@ -174,11 +174,11 @@ parse_status_tracking_options (SoupSoapParameter *group_param, guint i, EGwSendO
 {
 	SoupSoapParameter *subparam, *field_param, *val_param;
 
-	for (subparam = soup_soap_parameter_get_first_child_by_name(group_param, "setting") ;
-			     subparam != NULL ;
+	for (subparam = soup_soap_parameter_get_first_child_by_name(group_param, "setting");
+			     subparam != NULL;
 			     subparam = soup_soap_parameter_get_next_child_by_name (subparam, "setting")) {
 
-		char *field = NULL, *val = NULL;
+		gchar *field = NULL, *val = NULL;
 		field_param = soup_soap_parameter_get_first_child_by_name (subparam, "field");
 		val_param = soup_soap_parameter_get_first_child_by_name (subparam, "value");
 
@@ -229,7 +229,6 @@ parse_status_tracking_options (SoupSoapParameter *group_param, guint i, EGwSendO
 			} else
 				sopts->opened = E_GW_RETURN_NOTIFY_NONE;
 
-
 		} else if (!g_ascii_strcasecmp (field + i, "ReturnDelete")) {
 			if (val_param)
 				val_param = soup_soap_parameter_get_first_child_by_name (val_param, "mail");
@@ -254,7 +253,6 @@ parse_status_tracking_options (SoupSoapParameter *group_param, guint i, EGwSendO
 			} else
 				sopts->accepted = E_GW_RETURN_NOTIFY_NONE;
 
-
 		} else if (!g_ascii_strcasecmp (field + i, "ReturnCompleted")) {
 			if (val_param)
 				val_param = soup_soap_parameter_get_first_child_by_name (val_param, "mail");
@@ -282,10 +280,10 @@ parse_general_options (SoupSoapParameter *group_param, EGwSendOptionsGeneral *go
 {
 	SoupSoapParameter *subparam, *field_param, *val_param;
 
-	for (subparam = soup_soap_parameter_get_first_child_by_name(group_param, "setting") ;
-			     subparam != NULL ;
+	for (subparam = soup_soap_parameter_get_first_child_by_name(group_param, "setting");
+			     subparam != NULL;
 			     subparam = soup_soap_parameter_get_next_child_by_name (subparam, "setting")) {
-		char *field = NULL, *val = NULL;
+		gchar *field = NULL, *val = NULL;
 		field_param = soup_soap_parameter_get_first_child_by_name (subparam, "field");
 		val_param = soup_soap_parameter_get_first_child_by_name (subparam, "value");
 
@@ -316,15 +314,15 @@ parse_general_options (SoupSoapParameter *group_param, EGwSendOptionsGeneral *go
 		       if (val_param)
 				val = soup_soap_parameter_get_string_value (val_param);
 
-	       		if (val) {
+			if (val) {
 				if (!g_ascii_strcasecmp (val, "None"))
 					gopts->reply_enabled = FALSE;
 				else if (!g_ascii_strcasecmp (val, "WhenConvenient")) {
 					gopts->reply_enabled = TRUE;
 					gopts->reply_convenient = TRUE;
 				} else {
-					char *temp;
-					int i = 0;
+					gchar *temp;
+					gint i = 0;
 
 					val_param = soup_soap_parameter_get_first_child_by_name (val_param, "WithinNDays");
 					temp = soup_soap_parameter_get_string_value (val_param);
@@ -342,7 +340,7 @@ parse_general_options (SoupSoapParameter *group_param, EGwSendOptionsGeneral *go
 				val = soup_soap_parameter_get_string_value (val_param);
 
 			if (val) {
-				int i = atoi (val);
+				gint i = atoi (val);
 				if (i != 0)
 					gopts->expiration_enabled = TRUE;
 				else
@@ -364,10 +362,10 @@ parse_advanced_settings (SoupSoapParameter *group_param, EGwSendOptionsGeneral *
 {
 	SoupSoapParameter *subparam, *field_param, *val_param;
 
-	for (subparam = soup_soap_parameter_get_first_child_by_name(group_param, "setting") ;
-			     subparam != NULL ;
+	for (subparam = soup_soap_parameter_get_first_child_by_name(group_param, "setting");
+			     subparam != NULL;
 			     subparam = soup_soap_parameter_get_next_child_by_name (subparam, "setting")) {
-		char *field = NULL, *val = NULL;
+		gchar *field = NULL, *val = NULL;
 		field_param = soup_soap_parameter_get_first_child_by_name (subparam, "field");
 		val_param = soup_soap_parameter_get_first_child_by_name (subparam, "value");
 
@@ -406,14 +404,14 @@ e_gw_sendoptions_store_settings (SoupSoapParameter *param, EGwSendOptions *opts)
 
 	priv = opts->priv;
 
-	for (group_param = soup_soap_parameter_get_first_child_by_name(param, "group") ;
-			     group_param != NULL ;
+	for (group_param = soup_soap_parameter_get_first_child_by_name(param, "group");
+			     group_param != NULL;
 			     group_param = soup_soap_parameter_get_next_child_by_name (group_param, "group")) {
-		char *temp = NULL;
+		gchar *temp = NULL;
 
 		temp = soup_soap_parameter_get_property (group_param, "type");
 
-	        if (!temp)
+		if (!temp)
 			continue;
 
 		if (!g_ascii_strcasecmp (temp, "MailMessageSettings")) {
@@ -421,13 +419,13 @@ e_gw_sendoptions_store_settings (SoupSoapParameter *param, EGwSendOptions *opts)
 			parse_general_options (group_param, priv->gopts);
 		}
 
-	        if (!g_ascii_strcasecmp (temp, "AppointmentMessageSettings")) {
+		if (!g_ascii_strcasecmp (temp, "AppointmentMessageSettings")) {
 			parse_status_tracking_options (group_param, 11, priv->copts);
 		}
-	        if (!g_ascii_strcasecmp (temp, "TaskMessageSettings"))
+		if (!g_ascii_strcasecmp (temp, "TaskMessageSettings"))
 			parse_status_tracking_options (group_param, 4, priv->topts);
 
-	        if (!g_ascii_strcasecmp (temp, "AdvancedSettings"))
+		if (!g_ascii_strcasecmp (temp, "AdvancedSettings"))
 			parse_advanced_settings (group_param, priv->gopts);
 
 		g_free (temp);
@@ -437,7 +435,7 @@ e_gw_sendoptions_store_settings (SoupSoapParameter *param, EGwSendOptions *opts)
 }
 
 static void
-e_gw_sendoptions_write_settings (SoupSoapMessage *msg, char *field_name, char *value, char *value_name, gboolean value_direct)
+e_gw_sendoptions_write_settings (SoupSoapMessage *msg, const gchar *field_name, const gchar *value, const gchar *value_name, gboolean value_direct)
 {
 	soup_soap_message_start_element (msg, "setting", NULL, NULL);
 
@@ -458,9 +456,9 @@ e_gw_sendoptions_write_settings (SoupSoapMessage *msg, char *field_name, char *v
 }
 
 static void
-set_status_tracking_changes (SoupSoapMessage *msg, EGwSendOptionsStatusTracking *n_sopts, EGwSendOptionsStatusTracking *o_sopts, char *comp)
+set_status_tracking_changes (SoupSoapMessage *msg, EGwSendOptionsStatusTracking *n_sopts, EGwSendOptionsStatusTracking *o_sopts, const gchar *comp)
 {
-	char *value, *comp_name = NULL;
+	gchar *value, *comp_name = NULL;
 
 	if (n_sopts->tracking_enabled != o_sopts->tracking_enabled || n_sopts->track_when != o_sopts->track_when) {
 		if (n_sopts->tracking_enabled) {
@@ -556,7 +554,7 @@ set_status_tracking_changes (SoupSoapMessage *msg, EGwSendOptionsStatusTracking
 static void
 set_general_options_changes (SoupSoapMessage *msg, EGwSendOptionsGeneral *n_gopts, EGwSendOptionsGeneral *o_gopts)
 {
-	char *value;
+	gchar *value;
 
 	if (n_gopts->priority != o_gopts->priority) {
 		if (n_gopts->priority == E_GW_PRIORITY_HIGH)
@@ -659,4 +657,3 @@ e_gw_sendoptions_new_from_soap_parameter (SoupSoapParameter *param)
 	return opts;
 }
 
-
